province

# XMLRésuméLibrary: User Guide

projects | Element Reference | pub

## Name

province — A name or abbreviation of a province

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `province` element contains the name or abbreviation of a single province or similar political division.

### Parents

`province` may be contained in these elements: `address`, `location`

### Attributes

`id`

  A string used to uniquely identify a province. The province may then be referred to by this identifier.

## See Also

`county`, `state`.

## Examples

    <province>Saskatchewan</province>

    <province>BC</province>

projects | Element Reference | pub